==> solr-dataimporthandler-4.7.1-sources.jar: org/apache/solr/handler/dataimport/DIHWriterBase.java <==
package org.apache.solr.handler.dataimport;

/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.util.HashSet;
import java.util.Map;
import java.util.Set;

public abstract class DIHWriterBase implements DIHWriter {
  protected String keyFieldName;
  protected Set<Object> deltaKeys = null;
  
  @Override
  public void setDeltaKeys(Set<Map<String,Object>> passedInDeltaKeys) {
    deltaKeys = new HashSet<Object>();
    for (Map<String,Object> aMap : passedInDeltaKeys) {
      if (aMap.size() > 0) {
        Object key = null;
        if (keyFieldName != null) {
          key = aMap.get(keyFieldName);
        } else {
          key = aMap.entrySet().iterator().next();
        }
        if (key != null) {
          deltaKeys.add(key);
        }
      }
    }
  }
}

==> solr-dataimporthandler-5.2.1-sources.jar: org/apache/solr/handler/dataimport/DIHWriterBase.java <==
package org.apache.solr.handler.dataimport;

/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.util.HashSet;
import java.util.Map;
import java.util.Set;

public abstract class DIHWriterBase implements DIHWriter {
  protected String keyFieldName;
  protected Set<Object> deltaKeys = null;
  
  @Override
  public void setDeltaKeys(Set<Map<String,Object>> passedInDeltaKeys) {
    deltaKeys = new HashSet<>();
    for (Map<String,Object> aMap : passedInDeltaKeys) {
      if (aMap.size() > 0) {
        Object key = null;
        if (keyFieldName != null) {
          key = aMap.get(keyFieldName);
        } else {
          key = aMap.entrySet().iterator().next();
        }
        if (key != null) {
          deltaKeys.add(key);
        }
      }
    }
  }
}
